# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.2.6.2](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.7.1 
from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic import Field
import typing


class CreditTransaction(BaseModel):
    scenario: typing.Optional[str] = Field(default="") 
    user: typing.Optional[str] = Field(default="") 
    plan: typing.Optional[str] = Field(default="") 
    type: typing.Optional[str] = Field(default="") 
    meta_1_desc: typing.Optional[str] = Field(default="") 
    meta_1: typing.Optional[str] = Field(default="") 
    meta_2_desc: typing.Optional[str] = Field(default="") 
    meta_2: typing.Optional[str] = Field(default="") 
    meta_3_desc: typing.Optional[str] = Field(default="") 
    meta_3: typing.Optional[str] = Field(default="") 
    quantity: typing.Optional[float] = Field(default=0.0) 
    unit: typing.Optional[str] = Field(default="") 
    unit_price: typing.Optional[float] = Field(default=0.0) 
    credit: typing.Optional[float] = Field(default=0.0) 
    credit_dollar: typing.Optional[float] = Field(default=0.0) 
    date_extract: typing.Optional[str] = Field(default="") 

class Balance(BaseModel):
    balance: typing.Optional[float] = Field(default=0.0) 
    balance_dollar: typing.Optional[float] = Field(default=0.0) 



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.2.6.2](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.7.1 
from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic import Field
from uuid import UUID
import typing

class AIModelError(IntEnum):
    NO_ERROR = 0
    ALREADY_EXISTS = 1
    NOT_FOUND = 2
    NOT_UPDATED = 3
    NOT_AUTHORIZED = 4
    AIMODEL_OUT_OF_CREDITS = 5
    AIMODEL_DONT_HANDLE_COMPLETION = 6

class AIModel(BaseModel):
    id: typing.Optional[UUID] = Field(default="") 
    name: typing.Optional[str] = Field(default="") 
    provider: typing.Optional[str] = Field(default="") 
    image: typing.Optional[str] = Field(default="") 
    enabled: typing.Optional[bool] = Field(default=False) 
    type: typing.Optional[str] = Field(default="") 
    restricted: typing.Optional[bool] = Field(default=False) 
    name_alias: typing.Optional[str] = Field(default="") 
    context_window: typing.Optional[int] = Field(default=0) 

class CompletionResponse(BaseModel):
    model_id: typing.Optional[UUID] = Field(default="") 
    completions: typing.List[str] = Field(default_factory=list) 
    input_tokens: typing.Optional[int] = Field(default=0) 
    output_tokens: typing.Optional[int] = Field(default=0) 
    image_resolution: typing.Optional[str] = Field(default="") 
    image_steps: typing.Optional[int] = Field(default=0) 

class AIModelResponseError(BaseModel):
    code: typing.Optional[AIModelError] = Field(default=0) 
    status: typing.Optional[str] = Field(default="") 
    reason: typing.Optional[str] = Field(default="") 
    message: typing.Optional[str] = Field(default="") 

class AIModelListRequest(BaseModel):
    page_size: typing.Optional[int] = Field(default=0) 
    page_number: typing.Optional[int] = Field(default=0) 

class AIModelListResponse(BaseModel):
    aimodels: typing.List[AIModel] = Field(default_factory=list) 
    page_number: typing.Optional[int] = Field(default=0) 
    error: typing.Optional[AIModelResponseError] = Field(default=None) 

class AIModelGetRequest(BaseModel):
    id: typing.Optional[UUID] = Field(default="") 

class AIModelGetResponse(BaseModel):
    aimodel: typing.Optional[AIModel] = Field(default=None) 
    error: typing.Optional[AIModelResponseError] = Field(default=None) 

class AIModelCompletionRequest(BaseModel):
    id: typing.Optional[UUID] = Field(default="") 
    payload: typing.Optional[str] = Field(default="") 

class AIModelCompletionResponse(BaseModel):
    completion: typing.Optional[CompletionResponse] = Field(default=None) 
    error: typing.Optional[AIModelResponseError] = Field(default=None) 

class AIModelAdminCreationRequest(BaseModel):
    name: typing.Optional[str] = Field(default="") 
    provider: typing.Optional[str] = Field(default="") 
    image: typing.Optional[str] = Field(default="") 
    enabled: typing.Optional[bool] = Field(default=False) 
    type: typing.Optional[str] = Field(default="") 
    restricted: typing.Optional[bool] = Field(default=False) 
    name_alias: typing.Optional[str] = Field(default="") 

class AIModelAdminCreationResponse(BaseModel):
    aimodel: typing.Optional[AIModel] = Field(default=None) 
    error: typing.Optional[AIModelResponseError] = Field(default=None) 

class AIModelAdminDeleteRequest(BaseModel):
    id: typing.Optional[UUID] = Field(default="") 

class AIModelAdminDeleteResponse(BaseModel):
    error: typing.Optional[AIModelResponseError] = Field(default=None) 



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workspace.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fworkspace.proto\x12\tworkspace\x1a\x0evalidate.proto\"\x93\x04\n\tWorkspace\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08\x66\x61v_icon\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nlarge_logo\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\nsmall_logo\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1b\n\x0etertiary_color\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x1f\n\x12text_primary_color\x18\t \x01(\tH\x08\x88\x01\x01\x12!\n\x14text_secondary_color\x18\n \x01(\tH\t\x88\x01\x01\x12\x18\n\x0bis_personal\x18\x0b \x01(\x08H\n\x88\x01\x01\x12\x17\n\ncreated_at\x18\x0c \x01(\tH\x0b\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_nameB\x0b\n\t_fav_iconB\r\n\x0b_large_logoB\r\n\x0b_small_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x11\n\x0f_tertiary_colorB\x15\n\x13_text_primary_colorB\x17\n\x15_text_secondary_colorB\x0e\n\x0c_is_personalB\r\n\x0b_created_at\"\xd1\x03\n\x11WorkspaceCreation\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66\x61v_icon\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nlarge_logo\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nsmall_logo\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x1b\n\x0etertiary_color\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1f\n\x12text_primary_color\x18\x08 \x01(\tH\x07\x88\x01\x01\x12!\n\x14text_secondary_color\x18\t \x01(\tH\x08\x88\x01\x01\x12\x18\n\x0bis_personal\x18\n \x01(\x08H\t\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_fav_iconB\r\n\x0b_large_logoB\r\n\x0b_small_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x11\n\x0f_tertiary_colorB\x15\n\x13_text_primary_colorB\x17\n\x15_text_secondary_colorB\x0e\n\x0c_is_personal\"\xa5\x03\n\x0fWorkspaceUpdate\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66\x61v_icon\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nlarge_logo\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nsmall_logo\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x1b\n\x0etertiary_color\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x1f\n\x12text_primary_color\x18\t \x01(\tH\x07\x88\x01\x01\x12!\n\x14text_secondary_color\x18\n \x01(\tH\x08\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_fav_iconB\r\n\x0b_large_logoB\r\n\x0b_small_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x11\n\x0f_tertiary_colorB\x15\n\x13_text_primary_colorB\x17\n\x15_text_secondary_color\"\xb8\x02\n\rWorkspaceUser\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12.\n\x04role\x18\x03 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x02\x88\x01\x01\x12\x35\n\x06status\x18\x04 \x01(\tB \xfa\x42\x1dr\x1bR\x06\x61\x63tiveR\x07invitedR\x08\x64\x65\x63linedH\x03\x88\x01\x01\x12\x16\n\tcreate_at\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x16\n\tupdate_at\x18\x06 \x01(\tH\x05\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_idB\x07\n\x05_roleB\t\n\x07_statusB\x0c\n\n_create_atB\x0c\n\n_update_at\"\x90\x01\n\x13WorkspaceUserUpdate\x12.\n\x04role\x18\x01 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x00\x88\x01\x01\x12\x35\n\x06status\x18\x02 \x01(\tB \xfa\x42\x1dr\x1bR\x06\x61\x63tiveR\x07invitedR\x08\x64\x65\x63linedH\x01\x88\x01\x01\x42\x07\n\x05_roleB\t\n\x07_status\"\xb1\x01\n\x0fWorkspacePlugin\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12\x14\n\x07payload\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x16\n\tcreate_at\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x05\n\x03_idB\x0f\n\r_workspace_idB\n\n\x08_payloadB\x0c\n\n_create_at\"9\n\x15WorkspacePluginUpdate\x12\x14\n\x07payload\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_payload\"q\n\x16WorkspaceResponseError\x12,\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x19.workspace.WorkspaceErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_message\"B\n\x14WorkspaceListRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\n\n\x08_user_id\"\x82\x01\n\x15WorkspaceListResponse\x12(\n\nworkspaces\x18\x01 \x03(\x0b\x32\x14.workspace.Workspace\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x88\x01\n\x16WorkspaceCreateRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x34\n\tworkspace\x18\x02 \x01(\x0b\x32\x1c.workspace.WorkspaceCreationH\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0c\n\n_workspace\"\x96\x01\n\x17WorkspaceCreateResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"w\n\x13WorkspaceGetRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"\x93\x01\n\x14WorkspaceGetResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"\x90\x01\n\x16WorkspaceUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x32\n\tworkspace\x18\x02 \x01(\x0b\x32\x1a.workspace.WorkspaceUpdateH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_workspace\"\x96\x01\n\x17WorkspaceUpdateResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"z\n\x16WorkspaceDeleteRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"Z\n\x17WorkspaceDeleteResponse\x12\x35\n\x05\x65rror\x18\x01 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"P\n\x18WorkspaceUserListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x8f\x01\n\x19WorkspaceUserListResponse\x12\x31\n\x0fworkspace_users\x18\x01 \x03(\x0b\x32\x18.workspace.WorkspaceUser\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"{\n\x17WorkspaceUserGetRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"\xa5\x01\n\x18WorkspaceUserGetResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"\xce\x01\n\x1aWorkspaceUserUpdateRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12;\n\x0eworkspace_user\x18\x03 \x01(\x0b\x32\x1e.workspace.WorkspaceUserUpdateH\x02\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_idB\x11\n\x0f_workspace_user\"\xa8\x01\n\x1bWorkspaceUserUpdateResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"~\n\x1aWorkspaceUserDeleteRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"^\n\x1bWorkspaceUserDeleteResponse\x12\x35\n\x05\x65rror\x18\x01 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"v\n\x1cWorkspacePluginCreateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x14\n\x07payload\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\n\n\x08_payload\"\xb0\x01\n\x1dWorkspacePluginCreateResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"\x81\x01\n\x19WorkspacePluginGetRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_id\"\xad\x01\n\x1aWorkspacePluginGetResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"R\n\x1aWorkspacePluginListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x95\x01\n\x1bWorkspacePluginListResponse\x12\x35\n\x11workspace_plugins\x18\x01 \x03(\x0b\x32\x1a.workspace.WorkspacePlugin\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xda\x01\n\x1cWorkspacePluginUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12?\n\x10workspace_plugin\x18\x03 \x01(\x0b\x32 .workspace.WorkspacePluginUpdateH\x02\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_idB\x13\n\x11_workspace_plugin\"\xb0\x01\n\x1dWorkspacePluginUpdateResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"\x84\x01\n\x1cWorkspacePluginDeleteRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_id\"`\n\x1dWorkspacePluginDeleteResponse\x12\x35\n\x05\x65rror\x18\x01 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error*\x8b\x02\n\x0eWorkspaceError\x12\x16\n\x12WORKSPACE_NO_ERROR\x10\x00\x12\x17\n\x13WORKSPACE_NOT_FOUND\x10\x01\x12!\n\x1dWORKSPACE_USER_ALREADY_EXISTS\x10\x02\x12\x1c\n\x18WORKSPACE_USER_NOT_FOUND\x10\x03\x12!\n\x1dWORKSPACE_USER_ALREADY_ACTIVE\x10\x04\x12(\n$USER_ALREADY_HAVE_PERSONAL_WORKSPACE\x10\x05\x12\x1e\n\x1aWORKSPACE_PLUGIN_NOT_FOUND\x10\x06\x12\x1a\n\x15INTERNAL_SERVER_ERROR\x10\xe8\x07\x42\x32Z0github.com/jupyter-naas/naas-models/go/workspaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'workspace_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/jupyter-naas/naas-models/go/workspace'
  _globals['_WORKSPACE'].fields_by_name['id']._loaded_options = None
  _globals['_WORKSPACE'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSER'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSER'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSER'].fields_by_name['role']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _globals['_WORKSPACEUSER'].fields_by_name['status']._loaded_options = None
  _globals['_WORKSPACEUSER'].fields_by_name['status']._serialized_options = b'\372B\035r\033R\006activeR\007invitedR\010declined'
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['role']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['status']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATE'].fields_by_name['status']._serialized_options = b'\372B\035r\033R\006activeR\007invitedR\010declined'
  _globals['_WORKSPACEPLUGIN'].fields_by_name['id']._loaded_options = None
  _globals['_WORKSPACEPLUGIN'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGIN'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGIN'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACELISTREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACELISTREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACECREATEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACECREATEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERLISTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERLISTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['user_id']._loaded_options = None
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEUSERDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINCREATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINCREATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINGETREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINLISTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINLISTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINUPDATEREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_WORKSPACEPLUGINDELETEREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_WORKSPACEERROR']._serialized_start=6170
  _globals['_WORKSPACEERROR']._serialized_end=6437
  _globals['_WORKSPACE']._serialized_start=47
  _globals['_WORKSPACE']._serialized_end=578
  _globals['_WORKSPACECREATION']._serialized_start=581
  _globals['_WORKSPACECREATION']._serialized_end=1046
  _globals['_WORKSPACEUPDATE']._serialized_start=1049
  _globals['_WORKSPACEUPDATE']._serialized_end=1470
  _globals['_WORKSPACEUSER']._serialized_start=1473
  _globals['_WORKSPACEUSER']._serialized_end=1785
  _globals['_WORKSPACEUSERUPDATE']._serialized_start=1788
  _globals['_WORKSPACEUSERUPDATE']._serialized_end=1932
  _globals['_WORKSPACEPLUGIN']._serialized_start=1935
  _globals['_WORKSPACEPLUGIN']._serialized_end=2112
  _globals['_WORKSPACEPLUGINUPDATE']._serialized_start=2114
  _globals['_WORKSPACEPLUGINUPDATE']._serialized_end=2171
  _globals['_WORKSPACERESPONSEERROR']._serialized_start=2173
  _globals['_WORKSPACERESPONSEERROR']._serialized_end=2286
  _globals['_WORKSPACELISTREQUEST']._serialized_start=2288
  _globals['_WORKSPACELISTREQUEST']._serialized_end=2354
  _globals['_WORKSPACELISTRESPONSE']._serialized_start=2357
  _globals['_WORKSPACELISTRESPONSE']._serialized_end=2487
  _globals['_WORKSPACECREATEREQUEST']._serialized_start=2490
  _globals['_WORKSPACECREATEREQUEST']._serialized_end=2626
  _globals['_WORKSPACECREATERESPONSE']._serialized_start=2629
  _globals['_WORKSPACECREATERESPONSE']._serialized_end=2779
  _globals['_WORKSPACEGETREQUEST']._serialized_start=2781
  _globals['_WORKSPACEGETREQUEST']._serialized_end=2900
  _globals['_WORKSPACEGETRESPONSE']._serialized_start=2903
  _globals['_WORKSPACEGETRESPONSE']._serialized_end=3050
  _globals['_WORKSPACEUPDATEREQUEST']._serialized_start=3053
  _globals['_WORKSPACEUPDATEREQUEST']._serialized_end=3197
  _globals['_WORKSPACEUPDATERESPONSE']._serialized_start=3200
  _globals['_WORKSPACEUPDATERESPONSE']._serialized_end=3350
  _globals['_WORKSPACEDELETEREQUEST']._serialized_start=3352
  _globals['_WORKSPACEDELETEREQUEST']._serialized_end=3474
  _globals['_WORKSPACEDELETERESPONSE']._serialized_start=3476
  _globals['_WORKSPACEDELETERESPONSE']._serialized_end=3566
  _globals['_WORKSPACEUSERLISTREQUEST']._serialized_start=3568
  _globals['_WORKSPACEUSERLISTREQUEST']._serialized_end=3648
  _globals['_WORKSPACEUSERLISTRESPONSE']._serialized_start=3651
  _globals['_WORKSPACEUSERLISTRESPONSE']._serialized_end=3794
  _globals['_WORKSPACEUSERGETREQUEST']._serialized_start=3796
  _globals['_WORKSPACEUSERGETREQUEST']._serialized_end=3919
  _globals['_WORKSPACEUSERGETRESPONSE']._serialized_start=3922
  _globals['_WORKSPACEUSERGETRESPONSE']._serialized_end=4087
  _globals['_WORKSPACEUSERUPDATEREQUEST']._serialized_start=4090
  _globals['_WORKSPACEUSERUPDATEREQUEST']._serialized_end=4296
  _globals['_WORKSPACEUSERUPDATERESPONSE']._serialized_start=4299
  _globals['_WORKSPACEUSERUPDATERESPONSE']._serialized_end=4467
  _globals['_WORKSPACEUSERDELETEREQUEST']._serialized_start=4469
  _globals['_WORKSPACEUSERDELETEREQUEST']._serialized_end=4595
  _globals['_WORKSPACEUSERDELETERESPONSE']._serialized_start=4597
  _globals['_WORKSPACEUSERDELETERESPONSE']._serialized_end=4691
  _globals['_WORKSPACEPLUGINCREATEREQUEST']._serialized_start=4693
  _globals['_WORKSPACEPLUGINCREATEREQUEST']._serialized_end=4811
  _globals['_WORKSPACEPLUGINCREATERESPONSE']._serialized_start=4814
  _globals['_WORKSPACEPLUGINCREATERESPONSE']._serialized_end=4990
  _globals['_WORKSPACEPLUGINGETREQUEST']._serialized_start=4993
  _globals['_WORKSPACEPLUGINGETREQUEST']._serialized_end=5122
  _globals['_WORKSPACEPLUGINGETRESPONSE']._serialized_start=5125
  _globals['_WORKSPACEPLUGINGETRESPONSE']._serialized_end=5298
  _globals['_WORKSPACEPLUGINLISTREQUEST']._serialized_start=5300
  _globals['_WORKSPACEPLUGINLISTREQUEST']._serialized_end=5382
  _globals['_WORKSPACEPLUGINLISTRESPONSE']._serialized_start=5385
  _globals['_WORKSPACEPLUGINLISTRESPONSE']._serialized_end=5534
  _globals['_WORKSPACEPLUGINUPDATEREQUEST']._serialized_start=5537
  _globals['_WORKSPACEPLUGINUPDATEREQUEST']._serialized_end=5755
  _globals['_WORKSPACEPLUGINUPDATERESPONSE']._serialized_start=5758
  _globals['_WORKSPACEPLUGINUPDATERESPONSE']._serialized_end=5934
  _globals['_WORKSPACEPLUGINDELETEREQUEST']._serialized_start=5937
  _globals['_WORKSPACEPLUGINDELETEREQUEST']._serialized_end=6069
  _globals['_WORKSPACEPLUGINDELETERESPONSE']._serialized_start=6071
  _globals['_WORKSPACEPLUGINDELETERESPONSE']._serialized_end=6167
# @@protoc_insertion_point(module_scope)



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.2.6.2](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.7.1 
from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.get_desc.from_pb_option.types import UriRefStr
from pydantic import BaseModel
from pydantic import Field
from uuid import UUID
import typing

class SpaceError(IntEnum):
    SPACE_NO_ERROR = 0
    SPACE_ALREADY_EXISTS = 1
    SPACE_NOT_FOUND = 2
    SPACE_NOT_UPDATED = 3
    SPACE_MUST_HAVE_ONE_CONTAINER_PORT = 4

class Container(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9-]+)$") 
    image: typing.Optional[str] = Field(default="", min_length=1, pattern="^[a-zA-Z0-9\\.\\/-]+([:][a-zA-Z0-9\\.\\/-]*)?$") 
    env: typing.Dict[str, str] = Field(default_factory=dict) 
    port: typing.Optional[int] = Field(default=0, ge=0, le=65535) 
    cpu: typing.Optional[str] = Field(default="", pattern="^[1-9]+(.[1-9]+)?[m]?$") 
    memory: typing.Optional[str] = Field(default="", pattern="^[1-9]+(Mi|Gi|Ki)$") 

class ContainerUpdate(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9-]+)$") 
    image: typing.Optional[str] = Field(default="", min_length=1, pattern="^[a-zA-Z0-9\\.\\/-]+([:][a-zA-Z0-9\\.\\/-]*)?$") 
    env: typing.Dict[str, str] = Field(default_factory=dict) 
    port: typing.Optional[int] = Field(default=0, ge=0, le=65535) 
    cpu: typing.Optional[str] = Field(default="", pattern="^[1-9]+(.[1-9]+)?[m]?$") 
    memory: typing.Optional[str] = Field(default="", pattern="^[1-9]+(Mi|Gi|Ki)$") 

class Space(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 
    user_id: typing.Optional[UUID] = Field(default="") 
    id: typing.Optional[UUID] = Field(default="") 
    domain: typing.Optional[UriRefStr] = Field(default="") 
    containers: typing.List[Container] = Field(default_factory=list, min_length=1) 

class SpaceUpdate(BaseModel):
    domain: typing.Optional[UriRefStr] = Field(default="") 
    containers: typing.List[ContainerUpdate] = Field(default_factory=list, min_length=1) 

class SpaceResponseError(BaseModel):
    code: typing.Optional[SpaceError] = Field(default=0) 
    status: typing.Optional[str] = Field(default="") 
    reason: typing.Optional[str] = Field(default="") 
    message: typing.Optional[str] = Field(default="") 

class SpaceCreationRequest(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 
    domain: typing.Optional[UriRefStr] = Field(default="") 
    containers: typing.List[Container] = Field(default_factory=list, min_length=1) 

class SpaceCreationResponse(BaseModel):
    space: typing.Optional[Space] = Field(default=None) 
    status: typing.Optional[str] = Field(default="") 

class SpaceGetRequest(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 

class SpaceGetResponse(BaseModel):
    space: typing.Optional[Space] = Field(default=None) 
    status: typing.Optional[str] = Field(default="") 

class SpaceDeletionRequest(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 

class SpaceDeletionResponse(BaseModel):
    status: typing.Optional[str] = Field(default="") 

class SpaceListRequest(BaseModel):
    page_size: typing.Optional[int] = Field(default=0) 
    page_number: typing.Optional[int] = Field(default=0) 

class SpaceListResponse(BaseModel):
    spaces: typing.List[Space] = Field(default_factory=list) 

class SpaceUpdateRequest(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 
    space: typing.Optional[SpaceUpdate] = Field(default=None) 

class SpaceUpdateResponse(BaseModel):
    space: typing.Optional[Space] = Field(default=None) 
    status: typing.Optional[str] = Field(default="") 



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63ommon.proto\x12\x06\x63ommon\x1a\x0evalidate.proto\"$\n\tFieldMask\x12\x17\n\x05paths\x18\x01 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42/Z-github.com/jupyter-naas/naas-models/go/commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/jupyter-naas/naas-models/go/common'
  _globals['_FIELDMASK'].fields_by_name['paths']._loaded_options = None
  _globals['_FIELDMASK'].fields_by_name['paths']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_FIELDMASK']._serialized_start=40
  _globals['_FIELDMASK']._serialized_end=76
# @@protoc_insertion_point(module_scope)



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.2.6.2](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.7.1 
from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.customer_validator.v2 import in_validator
from pydantic import BaseModel
from pydantic import Field
from pydantic import field_validator
from uuid import UUID
import typing

class WorkspaceError(IntEnum):
    WORKSPACE_NO_ERROR = 0
    WORKSPACE_NOT_FOUND = 1
    WORKSPACE_USER_ALREADY_EXISTS = 2
    WORKSPACE_USER_NOT_FOUND = 3
    WORKSPACE_USER_ALREADY_ACTIVE = 4
    USER_ALREADY_HAVE_PERSONAL_WORKSPACE = 5
    WORKSPACE_PLUGIN_NOT_FOUND = 6
    INTERNAL_SERVER_ERROR = 1000

class Workspace(BaseModel):
    id: typing.Optional[UUID] = Field(default="") 
    name: typing.Optional[str] = Field(default="") 
    fav_icon: typing.Optional[str] = Field(default="") 
    large_logo: typing.Optional[str] = Field(default="") 
    small_logo: typing.Optional[str] = Field(default="") 
    primary_color: typing.Optional[str] = Field(default="") 
    secondary_color: typing.Optional[str] = Field(default="") 
    tertiary_color: typing.Optional[str] = Field(default="") 
    text_primary_color: typing.Optional[str] = Field(default="") 
    text_secondary_color: typing.Optional[str] = Field(default="") 
    is_personal: typing.Optional[bool] = Field(default=False) 
    created_at: typing.Optional[str] = Field(default="") 

class WorkspaceCreation(BaseModel):
    name: typing.Optional[str] = Field(default="") 
    fav_icon: typing.Optional[str] = Field(default="") 
    large_logo: typing.Optional[str] = Field(default="") 
    small_logo: typing.Optional[str] = Field(default="") 
    primary_color: typing.Optional[str] = Field(default="") 
    secondary_color: typing.Optional[str] = Field(default="") 
    tertiary_color: typing.Optional[str] = Field(default="") 
    text_primary_color: typing.Optional[str] = Field(default="") 
    text_secondary_color: typing.Optional[str] = Field(default="") 
    is_personal: typing.Optional[bool] = Field(default=False) 

class WorkspaceUpdate(BaseModel):
    name: typing.Optional[str] = Field(default="") 
    fav_icon: typing.Optional[str] = Field(default="") 
    large_logo: typing.Optional[str] = Field(default="") 
    small_logo: typing.Optional[str] = Field(default="") 
    primary_color: typing.Optional[str] = Field(default="") 
    secondary_color: typing.Optional[str] = Field(default="") 
    tertiary_color: typing.Optional[str] = Field(default="") 
    text_primary_color: typing.Optional[str] = Field(default="") 
    text_secondary_color: typing.Optional[str] = Field(default="") 

class WorkspaceUser(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="") 
    workspace_id: typing.Optional[UUID] = Field(default="") 
    role: typing.Optional[str] = Field(default="", in_=["owner", "admin", "member"]) 
    status: typing.Optional[str] = Field(default="", in_=["active", "invited", "declined"]) 
    create_at: typing.Optional[str] = Field(default="") 
    update_at: typing.Optional[str] = Field(default="") 

    role_in_validator = field_validator("role", mode="after",check_fields=None)(in_validator)
    status_in_validator = field_validator("status", mode="after",check_fields=None)(in_validator)

class WorkspaceUserUpdate(BaseModel):
    role: typing.Optional[str] = Field(default="", in_=["owner", "admin", "member"]) 
    status: typing.Optional[str] = Field(default="", in_=["active", "invited", "declined"]) 

    role_in_validator = field_validator("role", mode="after",check_fields=None)(in_validator)
    status_in_validator = field_validator("status", mode="after",check_fields=None)(in_validator)

class WorkspacePlugin(BaseModel):
    id: typing.Optional[UUID] = Field(default="") 
    workspace_id: typing.Optional[UUID] = Field(default="") 
    payload: typing.Optional[str] = Field(default="") 
    create_at: typing.Optional[str] = Field(default="") 

class WorkspacePluginUpdate(BaseModel):
    payload: typing.Optional[str] = Field(default="") 

class WorkspaceResponseError(BaseModel):
    code: typing.Optional[WorkspaceError] = Field(default=0) 
    message: typing.Optional[str] = Field(default="") 

class WorkspaceListRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="") 

class WorkspaceListResponse(BaseModel):
    workspaces: typing.List[Workspace] = Field(default_factory=list) 
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 

class WorkspaceCreateRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="") 
    workspace: typing.Optional[WorkspaceCreation] = Field(default=None) 

class WorkspaceCreateResponse(BaseModel):
    workspace: typing.Optional[Workspace] = Field(default=None) 
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 

class WorkspaceGetRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="") 
    workspace_id: typing.Optional[UUID] = Field(default="") 

class WorkspaceGetResponse(BaseModel):
    workspace: typing.Optional[Workspace] = Field(default=None) 
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 

class WorkspaceUpdateRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="") 
    workspace: typing.Optional[WorkspaceUpdate] = Field(default=None) 

class WorkspaceUpdateResponse(BaseModel):
    workspace: typing.Optional[Workspace] = Field(default=None) 
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 

class WorkspaceDeleteRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="") 
    workspace_id: typing.Optional[UUID] = Field(default="") 

class WorkspaceDeleteResponse(BaseModel):
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 

class WorkspaceUserListRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="") 

class WorkspaceUserListResponse(BaseModel):
    workspace_users: typing.List[WorkspaceUser] = Field(default_factory=list) 
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 

class WorkspaceUserGetRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="") 
    workspace_id: typing.Optional[UUID] = Field(default="") 

class WorkspaceUserGetResponse(BaseModel):
    workspace_user: typing.Optional[WorkspaceUser] = Field(default=None) 
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 

class WorkspaceUserUpdateRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="") 
    workspace_id: typing.Optional[UUID] = Field(default="") 
    workspace_user: typing.Optional[WorkspaceUserUpdate] = Field(default=None) 

class WorkspaceUserUpdateResponse(BaseModel):
    workspace_user: typing.Optional[WorkspaceUser] = Field(default=None) 
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 

class WorkspaceUserDeleteRequest(BaseModel):
    user_id: typing.Optional[UUID] = Field(default="") 
    workspace_id: typing.Optional[UUID] = Field(default="") 

class WorkspaceUserDeleteResponse(BaseModel):
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 

class WorkspacePluginCreateRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="") 
    payload: typing.Optional[str] = Field(default="") 

class WorkspacePluginCreateResponse(BaseModel):
    workspace_plugin: typing.Optional[WorkspacePlugin] = Field(default=None) 
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 

class WorkspacePluginGetRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="") 
    plugin_id: typing.Optional[UUID] = Field(default="") 

class WorkspacePluginGetResponse(BaseModel):
    workspace_plugin: typing.Optional[WorkspacePlugin] = Field(default=None) 
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 

class WorkspacePluginListRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="") 

class WorkspacePluginListResponse(BaseModel):
    workspace_plugins: typing.List[WorkspacePlugin] = Field(default_factory=list) 
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 

class WorkspacePluginUpdateRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="") 
    plugin_id: typing.Optional[UUID] = Field(default="") 
    workspace_plugin: typing.Optional[WorkspacePluginUpdate] = Field(default=None) 

class WorkspacePluginUpdateResponse(BaseModel):
    workspace_plugin: typing.Optional[WorkspacePlugin] = Field(default=None) 
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 

class WorkspacePluginDeleteRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="") 
    plugin_id: typing.Optional[UUID] = Field(default="") 

class WorkspacePluginDeleteResponse(BaseModel):
    error: typing.Optional[WorkspaceResponseError] = Field(default=None) 



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.2.6.2](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.7.1 
from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic import Field
import typing


class FieldMask(BaseModel):
    paths: typing.List[str] = Field(default_factory=list, min_length=1) 



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: registry.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eregistry.proto\x12\x08registry\x1a\x0evalidate.proto\"\x8f\x01\n\x08Registry\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12\x14\n\x07user_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x03uri\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x07\n\x05_nameB\n\n\x08_user_idB\x06\n\x04_uri\"]\n\x13RegistryCredentials\x12\x15\n\x08username\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08password\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_usernameB\x0b\n\t_password\"b\n\x17RegistryCreationRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"R\n\x18RegistryCreationResponse\x12)\n\x08registry\x18\x01 \x01(\x0b\x32\x12.registry.RegistryH\x00\x88\x01\x01\x42\x0b\n\t_registry\"\x84\x01\n\x1dRegistryCreationResponseError\x12+\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x17.registry.RegistryErrorH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x10\n\x0e_error_message\"e\n\x13RegistryListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\">\n\x14RegistryListResponse\x12&\n\nregistries\x18\x01 \x03(\x0b\x32\x12.registry.Registry\"]\n\x12RegistryGetRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"M\n\x13RegistryGetResponse\x12)\n\x08registry\x18\x01 \x01(\x0b\x32\x12.registry.RegistryH\x00\x88\x01\x01\x42\x0b\n\t_registry\"\x7f\n\x18RegistryGetResponseError\x12+\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x17.registry.RegistryErrorH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x10\n\x0e_error_message\"3\n\x15RegistryDeleteRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"\x82\x01\n\x1bRegistryDeleteResponseError\x12+\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x17.registry.RegistryErrorH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x10\n\x0e_error_message\"e\n\x1aRegistryCredentialsRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"\xaf\x01\n\x1bRegistryCredentialsResponse\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12\x37\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x1d.registry.RegistryCredentialsH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x0e\n\x0c_credentials\"\x87\x01\n RegistryCredentialsResponseError\x12+\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x17.registry.RegistryErrorH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x10\n\x0e_error_message*X\n\rRegistryError\x12\x1b\n\x17REGISTRY_ALREADY_EXISTS\x10\x00\x12\x16\n\x12REGISTRY_NOT_FOUND\x10\x01\x12\x12\n\x0eNOT_AUTHORIZED\x10\x02\x42\x31Z/github.com/jupyter-naas/naas-models/go/registryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'registry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/jupyter-naas/naas-models/go/registry'
  _globals['_REGISTRY'].fields_by_name['name']._loaded_options = None
  _globals['_REGISTRY'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_REGISTRYCREATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REGISTRYCREATIONREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_REGISTRYGETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REGISTRYGETREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_REGISTRYCREDENTIALSREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_REGISTRYCREDENTIALSREQUEST'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_REGISTRYCREDENTIALSRESPONSE'].fields_by_name['name']._loaded_options = None
  _globals['_REGISTRYCREDENTIALSRESPONSE'].fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _globals['_REGISTRYERROR']._serialized_start=1679
  _globals['_REGISTRYERROR']._serialized_end=1767
  _globals['_REGISTRY']._serialized_start=45
  _globals['_REGISTRY']._serialized_end=188
  _globals['_REGISTRYCREDENTIALS']._serialized_start=190
  _globals['_REGISTRYCREDENTIALS']._serialized_end=283
  _globals['_REGISTRYCREATIONREQUEST']._serialized_start=285
  _globals['_REGISTRYCREATIONREQUEST']._serialized_end=383
  _globals['_REGISTRYCREATIONRESPONSE']._serialized_start=385
  _globals['_REGISTRYCREATIONRESPONSE']._serialized_end=467
  _globals['_REGISTRYCREATIONRESPONSEERROR']._serialized_start=470
  _globals['_REGISTRYCREATIONRESPONSEERROR']._serialized_end=602
  _globals['_REGISTRYLISTREQUEST']._serialized_start=604
  _globals['_REGISTRYLISTREQUEST']._serialized_end=705
  _globals['_REGISTRYLISTRESPONSE']._serialized_start=707
  _globals['_REGISTRYLISTRESPONSE']._serialized_end=769
  _globals['_REGISTRYGETREQUEST']._serialized_start=771
  _globals['_REGISTRYGETREQUEST']._serialized_end=864
  _globals['_REGISTRYGETRESPONSE']._serialized_start=866
  _globals['_REGISTRYGETRESPONSE']._serialized_end=943
  _globals['_REGISTRYGETRESPONSEERROR']._serialized_start=945
  _globals['_REGISTRYGETRESPONSEERROR']._serialized_end=1072
  _globals['_REGISTRYDELETEREQUEST']._serialized_start=1074
  _globals['_REGISTRYDELETEREQUEST']._serialized_end=1125
  _globals['_REGISTRYDELETERESPONSEERROR']._serialized_start=1128
  _globals['_REGISTRYDELETERESPONSEERROR']._serialized_end=1258
  _globals['_REGISTRYCREDENTIALSREQUEST']._serialized_start=1260
  _globals['_REGISTRYCREDENTIALSREQUEST']._serialized_end=1361
  _globals['_REGISTRYCREDENTIALSRESPONSE']._serialized_start=1364
  _globals['_REGISTRYCREDENTIALSRESPONSE']._serialized_end=1539
  _globals['_REGISTRYCREDENTIALSRESPONSEERROR']._serialized_start=1542
  _globals['_REGISTRYCREDENTIALSRESPONSEERROR']._serialized_end=1677
# @@protoc_insertion_point(module_scope)



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.2.6.2](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.7.1 
from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic import Field
import typing

class RegistryError(IntEnum):
    REGISTRY_ALREADY_EXISTS = 0
    REGISTRY_NOT_FOUND = 1
    NOT_AUTHORIZED = 2

class Registry(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 
    user_id: typing.Optional[str] = Field(default="") 
    uri: typing.Optional[str] = Field(default="") 

class RegistryCredentials(BaseModel):
    username: typing.Optional[str] = Field(default="") 
    password: typing.Optional[str] = Field(default="") 

class RegistryCreationRequest(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 

class RegistryCreationResponse(BaseModel):
    registry: typing.Optional[Registry] = Field(default=None) 

class RegistryCreationResponseError(BaseModel):
    error: typing.Optional[RegistryError] = Field(default=0) 
    error_message: typing.Optional[str] = Field(default="") 

class RegistryListRequest(BaseModel):
    page_size: typing.Optional[int] = Field(default=0) 
    page_number: typing.Optional[int] = Field(default=0) 

class RegistryListResponse(BaseModel):
    registries: typing.List[Registry] = Field(default_factory=list) 

class RegistryGetRequest(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 

class RegistryGetResponse(BaseModel):
    registry: typing.Optional[Registry] = Field(default=None) 

class RegistryGetResponseError(BaseModel):
    error: typing.Optional[RegistryError] = Field(default=0) 
    error_message: typing.Optional[str] = Field(default="") 

class RegistryDeleteRequest(BaseModel):
    name: typing.Optional[str] = Field(default="") 

class RegistryDeleteResponseError(BaseModel):
    error: typing.Optional[RegistryError] = Field(default=0) 
    error_message: typing.Optional[str] = Field(default="") 

class RegistryCredentialsRequest(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 

class RegistryCredentialsResponse(BaseModel):
    name: typing.Optional[str] = Field(default="", min_length=1, max_length=63, pattern="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 
    credentials: typing.Optional[RegistryCredentials] = Field(default=None) 

class RegistryCredentialsResponseError(BaseModel):
    error: typing.Optional[RegistryError] = Field(default=0) 
    error_message: typing.Optional[str] = Field(default="") 



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.2.6.2](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.7.1 
from datetime import datetime
from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic import Field
from uuid import UUID
import typing

class AssetError(IntEnum):
    ASSET_NO_ERROR = 0
    ASSET_NOT_FOUND = 1
    ASSET_ALREADY_EXISTS = 2
    ASSET_REQUEST_ERROR = 3
    INTERNAL_SERVER_ERROR = 1000

class ObjectMetadata(BaseModel):
    provider: typing.Optional[str] = Field(default="") 
    provider_bucket_name: typing.Optional[str] = Field(default="") 
    workspace_id: typing.Optional[UUID] = Field(default="") 
    storage_name: typing.Optional[str] = Field(default="") 
    prefix: typing.Optional[str] = Field(default="") 
    object_name: typing.Optional[str] = Field(default="") 
    content_type: typing.Optional[str] = Field(default="") 
    content_length: typing.Optional[str] = Field(default="") 
    object_updated_at: typing.Optional[datetime] = Field(default_factory=datetime.now) 
    object_version: typing.Optional[str] = Field(default="") 
    metadata: typing.Optional[str] = Field(default="") 

class Asset(BaseModel):
    id: typing.Optional[UUID] = Field(default="") 
    object_name: typing.Optional[str] = Field(default="") 
    visibility: typing.Optional[str] = Field(default="") 
    content_disposition: typing.Optional[str] = Field(default="") 
    password: typing.Optional[str] = Field(default="") 
    url: typing.Optional[str] = Field(default="") 
    workspace_id: typing.Optional[UUID] = Field(default="") 
    storage_name: typing.Optional[str] = Field(default="") 
    prefix: typing.Optional[str] = Field(default="") 
    object_version: typing.Optional[str] = Field(default="") 
    content_type: typing.Optional[str] = Field(default="") 
    object_updated_at: typing.Optional[datetime] = Field(default_factory=datetime.now) 
    asset_created_at: typing.Optional[datetime] = Field(default_factory=datetime.now) 
    user_id: typing.Optional[UUID] = Field(default="") 
    provider: typing.Optional[str] = Field(default="") 
    provider_bucket_name: typing.Optional[str] = Field(default="") 

class AssetCreation(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="") 
    storage_name: typing.Optional[str] = Field(default="") 
    object_name: typing.Optional[str] = Field(default="") 
    object_version: typing.Optional[str] = Field(default="") 
    visibility: typing.Optional[str] = Field(default="") 
    content_disposition: typing.Optional[str] = Field(default="") 
    password: typing.Optional[str] = Field(default="") 

class AssetUpdate(BaseModel):
    visibility: typing.Optional[str] = Field(default="") 
    content_disposition: typing.Optional[str] = Field(default="") 

class AssetResponseError(BaseModel):
    code: typing.Optional[AssetError] = Field(default=0) 
    message: typing.Optional[str] = Field(default="") 

class AssetCreateRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="") 
    asset_creation: typing.Optional[AssetCreation] = Field(default=None) 

class AssetCreateResponse(BaseModel):
    asset: typing.Optional[Asset] = Field(default=None) 
    error: typing.Optional[AssetResponseError] = Field(default=None) 

class AssetGetRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="") 
    asset_id: typing.Optional[UUID] = Field(default="") 

class AssetGetResponse(BaseModel):
    asset: typing.Optional[Asset] = Field(default=None) 
    error: typing.Optional[AssetResponseError] = Field(default=None) 

class AssetGetObjectRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="") 
    asset_id: typing.Optional[UUID] = Field(default="") 

class AssetGetObjectResponse(BaseModel):
    url: typing.Optional[str] = Field(default="") 
    error: typing.Optional[AssetResponseError] = Field(default=None) 

class AssetUpdateRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="") 
    asset_update: typing.Optional[AssetUpdate] = Field(default=None) 

class AssetUpdateResponse(BaseModel):
    asset: typing.Optional[Asset] = Field(default=None) 
    error: typing.Optional[AssetResponseError] = Field(default=None) 

class AssetDeleteRequest(BaseModel):
    workspace_id: typing.Optional[UUID] = Field(default="") 
    asset_id: typing.Optional[UUID] = Field(default="") 

class AssetDeleteResponse(BaseModel):
    error: typing.Optional[AssetResponseError] = Field(default=None) 



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: asset.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61sset.proto\x12\x05\x61sset\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x0evalidate.proto\"\x9e\x04\n\x0eObjectMetadata\x12\x15\n\x08provider\x18\x01 \x01(\tH\x00\x88\x01\x01\x12!\n\x14provider_bucket_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x02\x88\x01\x01\x12\x19\n\x0cstorage_name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06prefix\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0bobject_name\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x19\n\x0c\x63ontent_type\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x1b\n\x0e\x63ontent_length\x18\x08 \x01(\tH\x07\x88\x01\x01\x12:\n\x11object_updated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x08\x88\x01\x01\x12\x1b\n\x0eobject_version\x18\n \x01(\tH\t\x88\x01\x01\x12\x15\n\x08metadata\x18\x0b \x01(\tH\n\x88\x01\x01\x42\x0b\n\t_providerB\x17\n\x15_provider_bucket_nameB\x0f\n\r_workspace_idB\x0f\n\r_storage_nameB\t\n\x07_prefixB\x0e\n\x0c_object_nameB\x0f\n\r_content_typeB\x11\n\x0f_content_lengthB\x14\n\x12_object_updated_atB\x11\n\x0f_object_versionB\x0b\n\t_metadata\"\xff\x05\n\x05\x41sset\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x18\n\x0bobject_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nvisibility\x18\x03 \x01(\tH\x02\x88\x01\x01\x12 \n\x13\x63ontent_disposition\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08password\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x10\n\x03url\x18\x06 \x01(\tH\x05\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x07 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x06\x88\x01\x01\x12\x19\n\x0cstorage_name\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x13\n\x06prefix\x18\t \x01(\tH\x08\x88\x01\x01\x12\x1b\n\x0eobject_version\x18\n \x01(\tH\t\x88\x01\x01\x12\x19\n\x0c\x63ontent_type\x18\x0b \x01(\tH\n\x88\x01\x01\x12:\n\x11object_updated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x0b\x88\x01\x01\x12\x39\n\x10\x61sset_created_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x0c\x88\x01\x01\x12\x1e\n\x07user_id\x18\x0e \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\r\x88\x01\x01\x12\x15\n\x08provider\x18\x0f \x01(\tH\x0e\x88\x01\x01\x12!\n\x14provider_bucket_name\x18\x10 \x01(\tH\x0f\x88\x01\x01\x42\x05\n\x03_idB\x0e\n\x0c_object_nameB\r\n\x0b_visibilityB\x16\n\x14_content_dispositionB\x0b\n\t_passwordB\x06\n\x04_urlB\x0f\n\r_workspace_idB\x0f\n\r_storage_nameB\t\n\x07_prefixB\x11\n\x0f_object_versionB\x0f\n\r_content_typeB\x14\n\x12_object_updated_atB\x13\n\x11_asset_created_atB\n\n\x08_user_idB\x0b\n\t_providerB\x17\n\x15_provider_bucket_name\"\xd1\x02\n\rAssetCreation\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x19\n\x0cstorage_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0bobject_name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1b\n\x0eobject_version\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\nvisibility\x18\x05 \x01(\tH\x04\x88\x01\x01\x12 \n\x13\x63ontent_disposition\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x15\n\x08password\x18\x07 \x01(\tH\x06\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0f\n\r_storage_nameB\x0e\n\x0c_object_nameB\x11\n\x0f_object_versionB\r\n\x0b_visibilityB\x16\n\x14_content_dispositionB\x0b\n\t_password\"o\n\x0b\x41ssetUpdate\x12\x17\n\nvisibility\x18\x01 \x01(\tH\x00\x88\x01\x01\x12 \n\x13\x63ontent_disposition\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\r\n\x0b_visibilityB\x16\n\x14_content_disposition\"e\n\x12\x41ssetResponseError\x12$\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x11.asset.AssetErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_message\"\x90\x01\n\x12\x41ssetCreateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x31\n\x0e\x61sset_creation\x18\x02 \x01(\x0b\x32\x14.asset.AssetCreationH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x11\n\x0f_asset_creation\"z\n\x13\x41ssetCreateResponse\x12 \n\x05\x61sset\x18\x01 \x01(\x0b\x32\x0c.asset.AssetH\x00\x88\x01\x01\x12-\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x19.asset.AssetResponseErrorH\x01\x88\x01\x01\x42\x08\n\x06_assetB\x08\n\x06_error\"u\n\x0f\x41ssetGetRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x1f\n\x08\x61sset_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0b\n\t_asset_id\"w\n\x10\x41ssetGetResponse\x12 \n\x05\x61sset\x18\x01 \x01(\x0b\x32\x0c.asset.AssetH\x00\x88\x01\x01\x12-\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x19.asset.AssetResponseErrorH\x01\x88\x01\x01\x42\x08\n\x06_assetB\x08\n\x06_error\"{\n\x15\x41ssetGetObjectRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x1f\n\x08\x61sset_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0b\n\t_asset_id\"k\n\x16\x41ssetGetObjectResponse\x12\x10\n\x03url\x18\x01 \x01(\tH\x00\x88\x01\x01\x12-\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x19.asset.AssetResponseErrorH\x01\x88\x01\x01\x42\x06\n\x04_urlB\x08\n\x06_error\"\x8a\x01\n\x12\x41ssetUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12-\n\x0c\x61sset_update\x18\x02 \x01(\x0b\x32\x12.asset.AssetUpdateH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0f\n\r_asset_update\"z\n\x13\x41ssetUpdateResponse\x12 \n\x05\x61sset\x18\x01 \x01(\x0b\x32\x0c.asset.AssetH\x00\x88\x01\x01\x12-\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x19.asset.AssetResponseErrorH\x01\x88\x01\x01\x42\x08\n\x06_assetB\x08\n\x06_error\"x\n\x12\x41ssetDeleteRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x1f\n\x08\x61sset_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0b\n\t_asset_id\"N\n\x13\x41ssetDeleteResponse\x12-\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x19.asset.AssetResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error*\x84\x01\n\nAssetError\x12\x12\n\x0e\x41SSET_NO_ERROR\x10\x00\x12\x13\n\x0f\x41SSET_NOT_FOUND\x10\x01\x12\x18\n\x14\x41SSET_ALREADY_EXISTS\x10\x02\x12\x17\n\x13\x41SSET_REQUEST_ERROR\x10\x03\x12\x1a\n\x15INTERNAL_SERVER_ERROR\x10\xe8\x07\x42.Z,github.com/jupyter-naas/naas-models/go/assetb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'asset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/jupyter-naas/naas-models/go/asset'
  _globals['_OBJECTMETADATA'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_OBJECTMETADATA'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSET'].fields_by_name['id']._loaded_options = None
  _globals['_ASSET'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSET'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSET'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSET'].fields_by_name['user_id']._loaded_options = None
  _globals['_ASSET'].fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETCREATION'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETCREATION'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETCREATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETCREATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETGETREQUEST'].fields_by_name['asset_id']._loaded_options = None
  _globals['_ASSETGETREQUEST'].fields_by_name['asset_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETGETOBJECTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETGETOBJECTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETGETOBJECTREQUEST'].fields_by_name['asset_id']._loaded_options = None
  _globals['_ASSETGETOBJECTREQUEST'].fields_by_name['asset_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETUPDATEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETUPDATEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETDELETEREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ASSETDELETEREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETDELETEREQUEST'].fields_by_name['asset_id']._loaded_options = None
  _globals['_ASSETDELETEREQUEST'].fields_by_name['asset_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ASSETERROR']._serialized_start=3155
  _globals['_ASSETERROR']._serialized_end=3287
  _globals['_OBJECTMETADATA']._serialized_start=72
  _globals['_OBJECTMETADATA']._serialized_end=614
  _globals['_ASSET']._serialized_start=617
  _globals['_ASSET']._serialized_end=1384
  _globals['_ASSETCREATION']._serialized_start=1387
  _globals['_ASSETCREATION']._serialized_end=1724
  _globals['_ASSETUPDATE']._serialized_start=1726
  _globals['_ASSETUPDATE']._serialized_end=1837
  _globals['_ASSETRESPONSEERROR']._serialized_start=1839
  _globals['_ASSETRESPONSEERROR']._serialized_end=1940
  _globals['_ASSETCREATEREQUEST']._serialized_start=1943
  _globals['_ASSETCREATEREQUEST']._serialized_end=2087
  _globals['_ASSETCREATERESPONSE']._serialized_start=2089
  _globals['_ASSETCREATERESPONSE']._serialized_end=2211
  _globals['_ASSETGETREQUEST']._serialized_start=2213
  _globals['_ASSETGETREQUEST']._serialized_end=2330
  _globals['_ASSETGETRESPONSE']._serialized_start=2332
  _globals['_ASSETGETRESPONSE']._serialized_end=2451
  _globals['_ASSETGETOBJECTREQUEST']._serialized_start=2453
  _globals['_ASSETGETOBJECTREQUEST']._serialized_end=2576
  _globals['_ASSETGETOBJECTRESPONSE']._serialized_start=2578
  _globals['_ASSETGETOBJECTRESPONSE']._serialized_end=2685
  _globals['_ASSETUPDATEREQUEST']._serialized_start=2688
  _globals['_ASSETUPDATEREQUEST']._serialized_end=2826
  _globals['_ASSETUPDATERESPONSE']._serialized_start=2828
  _globals['_ASSETUPDATERESPONSE']._serialized_end=2950
  _globals['_ASSETDELETEREQUEST']._serialized_start=2952
  _globals['_ASSETDELETEREQUEST']._serialized_end=3072
  _globals['_ASSETDELETERESPONSE']._serialized_start=3074
  _globals['_ASSETDELETERESPONSE']._serialized_end=3152
# @@protoc_insertion_point(module_scope)



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.2.6.2](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.7.1 
from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic import Field
import typing


class TokenData(BaseModel):
    user_id: typing.Optional[str] = Field(default="") 
    scopes: typing.List[str] = Field(default_factory=list) 

class Profile(BaseModel):
    user_id: typing.Optional[str] = Field(default="") 
    first_name: typing.Optional[str] = Field(default="") 
    last_name: typing.Optional[str] = Field(default="") 
    company: typing.Optional[str] = Field(default="") 
    role: typing.Optional[str] = Field(default="") 
    timezone: typing.Optional[str] = Field(default="") 
    profile_picture_url: typing.Optional[str] = Field(default="") 
    user_presentation: typing.Optional[str] = Field(default="") 
    targeted_use: typing.Optional[str] = Field(default="") 
    product_updates: typing.Optional[bool] = Field(default=False) 
    phone: typing.Optional[str] = Field(default="") 



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: credit.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63redit.proto\x12\x06\x63redit\x1a\x0evalidate.proto\"\xcb\x04\n\x11\x43reditTransaction\x12\x15\n\x08scenario\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04user\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04plan\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04type\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0bmeta_1_desc\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x13\n\x06meta_1\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x18\n\x0bmeta_2_desc\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x13\n\x06meta_2\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x18\n\x0bmeta_3_desc\x18\t \x01(\tH\x08\x88\x01\x01\x12\x13\n\x06meta_3\x18\n \x01(\tH\t\x88\x01\x01\x12\x15\n\x08quantity\x18\x0b \x01(\x02H\n\x88\x01\x01\x12\x11\n\x04unit\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x17\n\nunit_price\x18\r \x01(\x02H\x0c\x88\x01\x01\x12\x13\n\x06\x63redit\x18\x0e \x01(\x02H\r\x88\x01\x01\x12\x1a\n\rcredit_dollar\x18\x0f \x01(\x02H\x0e\x88\x01\x01\x12\x19\n\x0c\x64\x61te_extract\x18\x10 \x01(\tH\x0f\x88\x01\x01\x42\x0b\n\t_scenarioB\x07\n\x05_userB\x07\n\x05_planB\x07\n\x05_typeB\x0e\n\x0c_meta_1_descB\t\n\x07_meta_1B\x0e\n\x0c_meta_2_descB\t\n\x07_meta_2B\x0e\n\x0c_meta_3_descB\t\n\x07_meta_3B\x0b\n\t_quantityB\x07\n\x05_unitB\r\n\x0b_unit_priceB\t\n\x07_creditB\x10\n\x0e_credit_dollarB\x0f\n\r_date_extract\"[\n\x07\x42\x61lance\x12\x14\n\x07\x62\x61lance\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x1b\n\x0e\x62\x61lance_dollar\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\n\n\x08_balanceB\x11\n\x0f_balance_dollarB/Z-github.com/jupyter-naas/naas-models/go/creditb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'credit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/jupyter-naas/naas-models/go/credit'
  _globals['_CREDITTRANSACTION']._serialized_start=41
  _globals['_CREDITTRANSACTION']._serialized_end=628
  _globals['_BALANCE']._serialized_start=630
  _globals['_BALANCE']._serialized_end=721
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chat.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
import common_pb2 as common__pb2
import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nchat.proto\x12\x04\x63hat\x1a\x1cgoogle/protobuf/struct.proto\x1a\x0c\x63ommon.proto\x1a\x0evalidate.proto\"\xa8\x01\n\x14MessageResponseError\x12%\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x12.chat.MessageErrorH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06reason\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07message\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_codeB\t\n\x07_statusB\t\n\x07_reasonB\n\n\x08_message\"\xd4\x04\n\x07Message\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07version\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12!\n\ncreated_at\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x02\x88\x01\x01\x12\x14\n\x07\x63hat_id\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x16\n\tfrom_user\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x14\n\x07message\x18\x06 \x01(\tH\x05\x88\x01\x01\x12#\n\x0cmessage_type\x18\x07 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x06\x88\x01\x01\x12\'\n\x10message_language\x18\x08 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x07\x88\x01\x01\x12\x15\n\x08model_id\x18\t \x01(\tH\x08\x88\x01\x01\x12$\n\x04type\x18\n \x01(\x0e\x32\x11.chat.MessageTypeH\t\x88\x01\x01\x12\x15\n\x08metadata\x18\x0b \x01(\tH\n\x88\x01\x01\x12!\n\ndeleted_at\x18\x0c \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x0b\x88\x01\x01\x12\x15\n\x08selected\x18\r \x01(\x08H\x0c\x88\x01\x01\x12\"\n\x0b\x61rchived_at\x18\x0e \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\r\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_versionB\r\n\x0b_created_atB\n\n\x08_chat_idB\x0c\n\n_from_userB\n\n\x08_messageB\x0f\n\r_message_typeB\x13\n\x11_message_languageB\x0b\n\t_model_idB\x07\n\x05_typeB\x0b\n\t_metadataB\r\n\x0b_deleted_atB\x0b\n\t_selectedB\x0e\n\x0c_archived_at\"\xdc\x02\n\rMessageUpdate\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12#\n\x0cmessage_type\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x01\x88\x01\x01\x12\'\n\x10message_language\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x02\x88\x01\x01\x12\x15\n\x08metadata\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08selected\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\"\n\x0b\x61rchived_at\x18\x06 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x05\x88\x01\x01\x12*\n\nfield_mask\x18\x64 \x01(\x0b\x32\x11.common.FieldMaskH\x06\x88\x01\x01\x42\n\n\x08_messageB\x0f\n\r_message_typeB\x13\n\x11_message_languageB\x0b\n\t_metadataB\x0b\n\t_selectedB\x0e\n\x0c_archived_atB\r\n\x0b_field_mask\"+\n\x08Messages\x12\x1f\n\x08messages\x18\x01 \x03(\x0b\x32\r.chat.Message\"R\n\x16MessageDeletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07version\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_version\"K\n\x17MessageDeletionResponse\x12&\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x12.chat.MessageErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xad\x01\n\x19MessageRatinResponseError\x12%\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x12.chat.MessageErrorH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06reason\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07message\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_codeB\t\n\x07_statusB\t\n\x07_reasonB\n\n\x08_message\"\xef\x01\n\rMessageRating\x12\x17\n\nmessage_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07user_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0fmessage_version\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x17\n\ncreated_at\x18\x04 \x01(\tH\x03\x88\x01\x01\x12/\n\x06rating\x18\x05 \x01(\tB\x1a\xfa\x42\x17r\x15\x32\x10^(LIKE|DISLIKE)$\xd0\x01\x00H\x04\x88\x01\x01\x42\r\n\x0b_message_idB\n\n\x08_user_idB\x12\n\x10_message_versionB\r\n\x0b_created_atB\t\n\x07_rating\"\xb4\x01\n\x1cMessageRatingCreationRequest\x12\x17\n\nmessage_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1c\n\x0fmessage_version\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12/\n\x06rating\x18\x03 \x01(\tB\x1a\xfa\x42\x17r\x15\x32\x10^(LIKE|DISLIKE)$\xd0\x01\x00H\x02\x88\x01\x01\x42\r\n\x0b_message_idB\x12\n\x10_message_versionB\t\n\x07_rating\"\xa3\x01\n\x1dMessageRatingCreationResponse\x12\x33\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1f.chat.MessageRatinResponseErrorH\x00\x88\x01\x01\x12\x30\n\x0emessage_rating\x18\x02 \x01(\x0b\x32\x13.chat.MessageRatingH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x11\n\x0f_message_rating\"\xb6\x02\n\x04\x43hat\x12\x0f\n\x02id\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x17\n\ncreated_at\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07user_id\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\ndeleted_at\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x15\n\x08is_group\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\"\n\x15is_personal_assistant\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x17\n\nstarred_at\x18\x08 \x01(\tH\x07\x88\x01\x01\x42\x05\n\x03_idB\r\n\x0b_created_atB\n\n\x08_user_idB\x07\n\x05_nameB\r\n\x0b_deleted_atB\x0b\n\t_is_groupB\x18\n\x16_is_personal_assistantB\r\n\x0b_starred_at\"\xed\x01\n\nChatUpdate\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08is_group\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\"\n\x15is_personal_assistant\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x17\n\nstarred_at\x18\x04 \x01(\tH\x03\x88\x01\x01\x12*\n\nfield_mask\x18\x64 \x01(\x0b\x32\x11.common.FieldMaskH\x04\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_is_groupB\x18\n\x16_is_personal_assistantB\r\n\x0b_starred_atB\r\n\x0b_field_mask\"\x83\x01\n\x0c\x43hatMessages\x12\x32\n\x08messages\x18\x01 \x03(\x0b\x32 .chat.ChatMessages.MessagesEntry\x1a?\n\rMessagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.chat.Messages:\x02\x38\x01\"\xa2\x01\n\x11\x43hatResponseError\x12\"\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x0f.chat.ChatErrorH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06reason\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07message\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_codeB\t\n\x07_statusB\t\n\x07_reasonB\n\n\x08_message\"o\n\x13\x43hatCreationRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15is_personal_assistant\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x07\n\x05_nameB\x18\n\x16_is_personal_assistant\"u\n\x14\x43hatCreationResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12+\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\"(\n\x0e\x43hatGetRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"p\n\x0f\x43hatGetResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12+\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\"/\n\x15\x43hatMessageGetRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"\x87\x01\n\x16\x43hatMessageGetResponse\x12+\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x00\x88\x01\x01\x12)\n\x08messages\x18\x02 \x01(\x0b\x32\x12.chat.ChatMessagesH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x0b\n\t_messages\"-\n\x13\x43hatDeletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x03H\x00\x88\x01\x01\x42\x05\n\x03_id\"M\n\x14\x43hatDeletionResponse\x12+\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"g\n\x11\x43hatUpdateRequest\x12\x0f\n\x02id\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12*\n\x0b\x63hat_update\x18\x02 \x01(\x0b\x32\x10.chat.ChatUpdateH\x01\x88\x01\x01\x42\x05\n\x03_idB\x0e\n\x0c_chat_update\"s\n\x12\x43hatUpdateResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12+\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\"a\n\x0f\x43hatListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"c\n\x10\x43hatListResponse\x12\x18\n\x04\x63hat\x18\x01 \x03(\x0b\x32\n.chat.Chat\x12+\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"E\n\x0f\x43hatStarRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04star\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_star\"g\n\x10\x43hatStarResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12\"\n\x04\x63ode\x18\x02 \x01(\x0e\x32\x0f.chat.ChatErrorH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x07\n\x05_code\",\n\x12\x43hatArchiveRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"L\n\x13\x43hatArchiveResponse\x12+\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xa5\x02\n\x12\x43ompletionResponse\x12\x1f\n\x08messages\x18\x01 \x03(\x0b\x32\r.chat.Message\x12\x19\n\x0cinput_tokens\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x1a\n\routput_tokens\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x1d\n\x10image_resolution\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0bimage_steps\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12+\n\x06status\x18\x06 \x01(\x0e\x32\x16.chat.CompletionStatusH\x04\x88\x01\x01\x42\x0f\n\r_input_tokensB\x10\n\x0e_output_tokensB\x13\n\x11_image_resolutionB\x0e\n\x0c_image_stepsB\t\n\x07_status\"c\n\x0b\x42\x61sePayload\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03url\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06prompt\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x07\n\x05_nameB\x06\n\x04_urlB\t\n\x07_prompt\"\xa5\x01\n\x15\x43hatCompletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x15\n\x08model_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07payload\x18\x03 \x01(\tH\x02\x88\x01\x01\x12 \n\tplugin_id\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x03\x88\x01\x01\x42\x05\n\x03_idB\x0b\n\t_model_idB\n\n\x08_payloadB\x0c\n\n_plugin_id\"3\n\x19\x43hatStopCompletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"S\n\x1a\x43hatStopCompletionResponse\x12+\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x91\x01\n\x16\x43hatCompletionResponse\x12\x31\n\ncompletion\x18\x01 \x01(\x0b\x32\x18.chat.CompletionResponseH\x00\x88\x01\x01\x12+\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x01\x88\x01\x01\x42\r\n\x0b_completionB\x08\n\x06_error*;\n\x0bMessageType\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x12\x06\n\x02\x41I\x10\x02\x12\t\n\x05HUMAN\x10\x03*\xb0\x01\n\x0cMessageError\x12\x14\n\x10MESSAGE_NO_ERROR\x10\x00\x12\x1a\n\x16MESSAGE_ALREADY_EXISTS\x10\x01\x12\x15\n\x11MESSAGE_NOT_FOUND\x10\x02\x12\x17\n\x13MESSAGE_NOT_UPDATED\x10\x03\x12\x1a\n\x16MESSAGE_NOT_AUTHORIZED\x10\x04\x12\"\n\x1dMESSAGE_INTERNAL_SERVER_ERROR\x10\xe8\x07*:\n\x10\x43ompletionStatus\x12\r\n\tCOMPLETED\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x12\x0b\n\x07TIMEOUT\x10\x02*\x9e\x02\n\tChatError\x12\x11\n\rCHAT_NO_ERROR\x10\x00\x12\x17\n\x13\x43HAT_ALREADY_EXISTS\x10\x01\x12\x12\n\x0e\x43HAT_NOT_FOUND\x10\x02\x12\x14\n\x10\x43HAT_NOT_UPDATED\x10\x03\x12\x17\n\x13\x43HAT_NOT_AUTHORIZED\x10\x04\x12+\n\'CHAT_COMPLETION_ADAPTOR_DOES_NOT_EXISTS\x10\x05\x12\x1a\n\x16\x43HAT_AIMODEL_NOT_FOUND\x10\x06\x12\x16\n\x12\x43HAT_OUT_OF_CREDIT\x10\x07\x12 \n\x1c\x43HAT_CONTEXT_LENGTH_EXCEEDED\x10\x08\x12\x1f\n\x1a\x43HAT_INTERNAL_SERVER_ERROR\x10\xe8\x07\x32\xfa\x02\n\x0b\x43hatService\x12\x41\n\x06\x43reate\x12\x19.chat.ChatCreationRequest\x1a\x1a.chat.ChatCreationResponse\"\x00\x12\x34\n\x03Get\x12\x14.chat.ChatGetRequest\x1a\x15.chat.ChatGetResponse\"\x00\x12\x37\n\x04List\x12\x15.chat.ChatListRequest\x1a\x16.chat.ChatListResponse\"\x00\x12\x41\n\x06\x44\x65lete\x12\x19.chat.ChatDeletionRequest\x1a\x1a.chat.ChatDeletionResponse\"\x00\x12=\n\x06Update\x12\x17.chat.ChatUpdateRequest\x1a\x18.chat.ChatUpdateResponse\"\x00\x12\x37\n\x04Star\x12\x15.chat.ChatStarRequest\x1a\x16.chat.ChatStarResponse\"\x00\x42-Z+github.com/jupyter-naas/naas-models/go/chatb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'chat_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/jupyter-naas/naas-models/go/chat'
  _globals['_MESSAGE'].fields_by_name['created_at']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['created_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGE'].fields_by_name['message_type']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['message_type']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGE'].fields_by_name['message_language']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['message_language']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGE'].fields_by_name['deleted_at']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['deleted_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGE'].fields_by_name['archived_at']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['archived_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGEUPDATE'].fields_by_name['message_type']._loaded_options = None
  _globals['_MESSAGEUPDATE'].fields_by_name['message_type']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGEUPDATE'].fields_by_name['message_language']._loaded_options = None
  _globals['_MESSAGEUPDATE'].fields_by_name['message_language']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGEUPDATE'].fields_by_name['archived_at']._loaded_options = None
  _globals['_MESSAGEUPDATE'].fields_by_name['archived_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGERATING'].fields_by_name['rating']._loaded_options = None
  _globals['_MESSAGERATING'].fields_by_name['rating']._serialized_options = b'\372B\027r\0252\020^(LIKE|DISLIKE)$\320\001\000'
  _globals['_MESSAGERATINGCREATIONREQUEST'].fields_by_name['rating']._loaded_options = None
  _globals['_MESSAGERATINGCREATIONREQUEST'].fields_by_name['rating']._serialized_options = b'\372B\027r\0252\020^(LIKE|DISLIKE)$\320\001\000'
  _globals['_CHATMESSAGES_MESSAGESENTRY']._loaded_options = None
  _globals['_CHATMESSAGES_MESSAGESENTRY']._serialized_options = b'8\001'
  _globals['_CHATCOMPLETIONREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_CHATCOMPLETIONREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_MESSAGETYPE']._serialized_start=5300
  _globals['_MESSAGETYPE']._serialized_end=5359
  _globals['_MESSAGEERROR']._serialized_start=5362
  _globals['_MESSAGEERROR']._serialized_end=5538
  _globals['_COMPLETIONSTATUS']._serialized_start=5540
  _globals['_COMPLETIONSTATUS']._serialized_end=5598
  _globals['_CHATERROR']._serialized_start=5601
  _globals['_CHATERROR']._serialized_end=5887
  _globals['_MESSAGERESPONSEERROR']._serialized_start=81
  _globals['_MESSAGERESPONSEERROR']._serialized_end=249
  _globals['_MESSAGE']._serialized_start=252
  _globals['_MESSAGE']._serialized_end=848
  _globals['_MESSAGEUPDATE']._serialized_start=851
  _globals['_MESSAGEUPDATE']._serialized_end=1199
  _globals['_MESSAGES']._serialized_start=1201
  _globals['_MESSAGES']._serialized_end=1244
  _globals['_MESSAGEDELETIONREQUEST']._serialized_start=1246
  _globals['_MESSAGEDELETIONREQUEST']._serialized_end=1328
  _globals['_MESSAGEDELETIONRESPONSE']._serialized_start=1330
  _globals['_MESSAGEDELETIONRESPONSE']._serialized_end=1405
  _globals['_MESSAGERATINRESPONSEERROR']._serialized_start=1408
  _globals['_MESSAGERATINRESPONSEERROR']._serialized_end=1581
  _globals['_MESSAGERATING']._serialized_start=1584
  _globals['_MESSAGERATING']._serialized_end=1823
  _globals['_MESSAGERATINGCREATIONREQUEST']._serialized_start=1826
  _globals['_MESSAGERATINGCREATIONREQUEST']._serialized_end=2006
  _globals['_MESSAGERATINGCREATIONRESPONSE']._serialized_start=2009
  _globals['_MESSAGERATINGCREATIONRESPONSE']._serialized_end=2172
  _globals['_CHAT']._serialized_start=2175
  _globals['_CHAT']._serialized_end=2485
  _globals['_CHATUPDATE']._serialized_start=2488
  _globals['_CHATUPDATE']._serialized_end=2725
  _globals['_CHATMESSAGES']._serialized_start=2728
  _globals['_CHATMESSAGES']._serialized_end=2859
  _globals['_CHATMESSAGES_MESSAGESENTRY']._serialized_start=2796
  _globals['_CHATMESSAGES_MESSAGESENTRY']._serialized_end=2859
  _globals['_CHATRESPONSEERROR']._serialized_start=2862
  _globals['_CHATRESPONSEERROR']._serialized_end=3024
  _globals['_CHATCREATIONREQUEST']._serialized_start=3026
  _globals['_CHATCREATIONREQUEST']._serialized_end=3137
  _globals['_CHATCREATIONRESPONSE']._serialized_start=3139
  _globals['_CHATCREATIONRESPONSE']._serialized_end=3256
  _globals['_CHATGETREQUEST']._serialized_start=3258
  _globals['_CHATGETREQUEST']._serialized_end=3298
  _globals['_CHATGETRESPONSE']._serialized_start=3300
  _globals['_CHATGETRESPONSE']._serialized_end=3412
  _globals['_CHATMESSAGEGETREQUEST']._serialized_start=3414
  _globals['_CHATMESSAGEGETREQUEST']._serialized_end=3461
  _globals['_CHATMESSAGEGETRESPONSE']._serialized_start=3464
  _globals['_CHATMESSAGEGETRESPONSE']._serialized_end=3599
  _globals['_CHATDELETIONREQUEST']._serialized_start=3601
  _globals['_CHATDELETIONREQUEST']._serialized_end=3646
  _globals['_CHATDELETIONRESPONSE']._serialized_start=3648
  _globals['_CHATDELETIONRESPONSE']._serialized_end=3725
  _globals['_CHATUPDATEREQUEST']._serialized_start=3727
  _globals['_CHATUPDATEREQUEST']._serialized_end=3830
  _globals['_CHATUPDATERESPONSE']._serialized_start=3832
  _globals['_CHATUPDATERESPONSE']._serialized_end=3947
  _globals['_CHATLISTREQUEST']._serialized_start=3949
  _globals['_CHATLISTREQUEST']._serialized_end=4046
  _globals['_CHATLISTRESPONSE']._serialized_start=4048
  _globals['_CHATLISTRESPONSE']._serialized_end=4147
  _globals['_CHATSTARREQUEST']._serialized_start=4149
  _globals['_CHATSTARREQUEST']._serialized_end=4218
  _globals['_CHATSTARRESPONSE']._serialized_start=4220
  _globals['_CHATSTARRESPONSE']._serialized_end=4323
  _globals['_CHATARCHIVEREQUEST']._serialized_start=4325
  _globals['_CHATARCHIVEREQUEST']._serialized_end=4369
  _globals['_CHATARCHIVERESPONSE']._serialized_start=4371
  _globals['_CHATARCHIVERESPONSE']._serialized_end=4447
  _globals['_COMPLETIONRESPONSE']._serialized_start=4450
  _globals['_COMPLETIONRESPONSE']._serialized_end=4743
  _globals['_BASEPAYLOAD']._serialized_start=4745
  _globals['_BASEPAYLOAD']._serialized_end=4844
  _globals['_CHATCOMPLETIONREQUEST']._serialized_start=4847
  _globals['_CHATCOMPLETIONREQUEST']._serialized_end=5012
  _globals['_CHATSTOPCOMPLETIONREQUEST']._serialized_start=5014
  _globals['_CHATSTOPCOMPLETIONREQUEST']._serialized_end=5065
  _globals['_CHATSTOPCOMPLETIONRESPONSE']._serialized_start=5067
  _globals['_CHATSTOPCOMPLETIONRESPONSE']._serialized_end=5150
  _globals['_CHATCOMPLETIONRESPONSE']._serialized_start=5153
  _globals['_CHATCOMPLETIONRESPONSE']._serialized_end=5298
  _globals['_CHATSERVICE']._serialized_start=5890
  _globals['_CHATSERVICE']._serialized_end=6268
# @@protoc_insertion_point(module_scope)
